@@ -1,6 +1,5 @@
-#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #  SPDX-License-Identifier: Apache-2.0
-import copy
 import json
 import logging
 import os
@@ -11,11 +10,11 @@ import yamale
 import yaml
 from betterboto import client as betterboto_client
 
-from servicecatalog_puppet import yaml_utils
 from servicecatalog_puppet import asset_helpers
 from servicecatalog_puppet import config
 from servicecatalog_puppet import constants
 from servicecatalog_puppet import manifest_utils
+from servicecatalog_puppet import yaml_utils
 
 logger = logging.getLogger(__name__)
 
@@ -55,7 +54,7 @@ def assemble_manifest_from_ssm(target_directory):
         )
 
 
-def expand(f, puppet_account_id, single_account, subset=None):
+def expand(f, puppet_account_id, regions, single_account, subset=None):
     click.echo("Expanding")
     target_directory = os.path.sep.join([os.path.dirname(f.name), "manifests"])
     assemble_manifest_from_ssm(target_directory)
@@ -93,7 +92,6 @@ def expand(f, puppet_account_id, single_account, subset=None):
                     if str(deploy_details.get("account_id")) == str(single_account):
                         accounts.append(deploy_details)
 
-                print(f"{item_name}: there are " + str(len(accounts)))
                 if item.get(deploy_to_name).get("accounts"):
                     if len(accounts) > 0:
                         item[deploy_to_name]["accounts"] = accounts
@@ -132,7 +130,6 @@ def expand(f, puppet_account_id, single_account, subset=None):
     # handle all accounts
     sct_manifest_accounts = json.dumps(manifest_accounts_all)
     sct_manifest_spokes = json.dumps(manifest_accounts_excluding)
-    regions = config.get_regions(puppet_account_id)
     sct_config_regions = json.dumps(regions)
 
     new_manifest["parameters"]["SCTManifestAccounts"] = dict(
@@ -145,26 +142,6 @@ def expand(f, puppet_account_id, single_account, subset=None):
     if new_manifest.get(constants.LAMBDA_INVOCATIONS) is None:
         new_manifest[constants.LAMBDA_INVOCATIONS] = dict()
 
-    home_region = config.get_home_region(puppet_account_id)
-    with betterboto_client.ClientContextManager("ssm") as ssm:
-        response = ssm.get_parameter(Name="service-catalog-puppet-version")
-        version = response.get("Parameter").get("Value")
-
-    new_manifest["config_cache"] = dict(
-        home_region=home_region,
-        regions=regions,
-        should_collect_cloudformation_events=config.get_should_use_sns(
-            puppet_account_id, home_region
-        ),
-        should_forward_events_to_eventbridge=config.get_should_use_eventbridge(
-            puppet_account_id, home_region
-        ),
-        should_forward_failures_to_opscenter=config.get_should_forward_failures_to_opscenter(
-            puppet_account_id, home_region
-        ),
-        puppet_version=version,
-    )
-
     new_name = f.name.replace(".yaml", "-expanded.yaml")
     logger.info("Writing new manifest: {}".format(new_name))
     with open(new_name, "w") as output:
