@@ -1,34 +1,26 @@
-#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #  SPDX-License-Identifier: Apache-2.0
+import json
 import re
 
 import luigi
 
 from servicecatalog_puppet import config
 from servicecatalog_puppet import utils
+from servicecatalog_puppet.workflow.dependencies import tasks
 from servicecatalog_puppet.workflow.general import delete_cloud_formation_stack_task
-from servicecatalog_puppet.workflow.portfolio.portfolio_management import (
-    create_spoke_local_portfolio_task,
-)
-from servicecatalog_puppet.workflow.portfolio.portfolio_management import (
-    portfolio_management_task,
-)
 
 
-class CreateAssociationsForSpokeLocalPortfolioTask(
-    portfolio_management_task.PortfolioManagementTask
-):
+class CreateAssociationsForSpokeLocalPortfolioTask(tasks.TaskWithReference):
+    portfolio_task_reference = luigi.Parameter()
     spoke_local_portfolio_name = luigi.Parameter()
     account_id = luigi.Parameter()
     region = luigi.Parameter()
     portfolio = luigi.Parameter()
     puppet_account_id = luigi.Parameter()
-    organization = luigi.Parameter()
 
     associations = luigi.ListParameter(default=[])
 
-    sharing_mode = luigi.Parameter()
-
     def params_for_results_display(self):
         return {
             "puppet_account_id": self.puppet_account_id,
@@ -39,19 +31,6 @@ class CreateAssociationsForSpokeLocalPortfolioTask(
             "cache_invalidator": self.cache_invalidator,
         }
 
-    def requires(self):
-        return {
-            "create_spoke_local_portfolio_task": create_spoke_local_portfolio_task.CreateSpokeLocalPortfolioTask(
-                manifest_file_path=self.manifest_file_path,
-                puppet_account_id=self.puppet_account_id,
-                account_id=self.account_id,
-                region=self.region,
-                portfolio=self.portfolio,
-                organization=self.organization,
-                sharing_mode=self.sharing_mode,
-            ),
-        }
-
     def api_calls_used(self):
         calls = [
             f"cloudformation.create_or_update_{self.account_id}_{self.region}",
@@ -63,11 +42,14 @@ class CreateAssociationsForSpokeLocalPortfolioTask(
         return calls
 
     def run(self):
-        create_spoke_local_portfolio_task_input = self.load_from_input(
-            "create_spoke_local_portfolio_task"
+        portfolio_details = json.loads(
+            self.input()
+            .get("reference_dependencies")
+            .get(self.portfolio_task_reference)
+            .open("r")
+            .read()
         )
-        portfolio_id = create_spoke_local_portfolio_task_input.get("Id")
-        self.info(f"using portfolio_id: {portfolio_id}")
+        portfolio_id = portfolio_details.get("Id")
 
         yield delete_cloud_formation_stack_task.DeleteCloudFormationStackTask(
             account_id=self.account_id,
@@ -109,7 +91,6 @@ class CreateAssociationsForSpokeLocalPortfolioTask(
                 portfolio_id=portfolio_id,
             )
             stack_name = f"associations-for-{utils.slugify_for_cloudformation_stack_name(self.spoke_local_portfolio_name)}"
-            self.info(template)
             cloudformation.create_or_update(
                 StackName=stack_name,
                 TemplateBody=template,
