@@ -1,4 +1,4 @@
-#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #  SPDX-License-Identifier: Apache-2.0
 
 import io
@@ -8,20 +8,11 @@ import zipfile
 import luigi
 
 from servicecatalog_puppet import constants
-from servicecatalog_puppet.workflow import dependency
-from servicecatalog_puppet.workflow.general import get_ssm_param_task
-from servicecatalog_puppet.workflow.manifest import manifest_mixin
+from servicecatalog_puppet.workflow.dependencies import tasks
 from servicecatalog_puppet.workflow.workspaces import Limits
-from servicecatalog_puppet.workflow.workspaces import prepare_account_for_workspace_task
-from servicecatalog_puppet.workflow.workspaces import workspace_base_task
 
 
-class ProvisionWorkspaceTask(
-    workspace_base_task.WorkspaceBaseTask,
-    get_ssm_param_task.PuppetTaskWithParameters,
-    manifest_mixin.ManifestMixen,
-    dependency.DependenciesMixin,
-):
+class ProvisionWorkspaceTask(tasks.TaskWithParameters):
     workspace_name = luigi.Parameter()
     region = luigi.Parameter()
     account_id = luigi.Parameter()
@@ -44,6 +35,13 @@ class ProvisionWorkspaceTask(
     requested_priority = luigi.IntParameter(significant=False, default=0)
 
     execution = luigi.Parameter()
+    manifest_file_path = luigi.Parameter()
+
+    section_name = constants.WORKSPACES
+
+    @property
+    def item_name(self):
+        return self.workspace_name
 
     def params_for_results_display(self):
         return {
@@ -54,19 +52,6 @@ class ProvisionWorkspaceTask(
             "cache_invalidator": self.cache_invalidator,
         }
 
-    def requires(self):
-        requirements = {
-            "section_dependencies": self.get_section_dependencies(),
-            "ssm_params": self.get_parameters_tasks(),
-        }
-        if not self.is_running_in_spoke():
-            requirements[
-                "account_ready"
-            ] = prepare_account_for_workspace_task.PrepareAccountForWorkspaceTask(
-                puppet_account_id=self.puppet_account_id, account_id=self.account_id,
-            )
-        return requirements
-
     def resources_used(self):
         return [
             (self.account_id, Limits.CODEBUILD_CONCURRENT_PROJECTS),
